@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Parameter/BinaryParameter.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -574,20 +574,19 @@ void BinaryParameter::edit(std::ofstream & oFile, bool text) {
 	}
 
 	// Write in output numeric files
-	else {
-		for (k = 0; k < _nbCluster; k++) {
+  else {
+    for (k = 0; k < _nbCluster; k++) {
+			putDoubleInStream(oFile, _tabProportion[k]);
 
-			oFile << _tabProportion[k] << endl;
+      for (j = 0; j < _pbDimension; j++)
+        oFile << _tabCenter[k][j] << "  ";
+      oFile << endl;
+      editScatter(oFile, k, text); // virtual
+      oFile << endl << endl;
 
-			for (j = 0; j < _pbDimension; j++)
-				oFile << _tabCenter[k][j] << "  ";
-			oFile << endl;
-			editScatter(oFile, k, text); // virtual
-			oFile << endl << endl;
-
-		}// end for k
-		oFile << endl;
-	}
+    }// end for k
+    oFile << endl;
+  }
 }
 
 //------------------------------
@@ -596,18 +595,17 @@ void BinaryParameter::edit(std::ofstream & oFile, bool text) {
 void BinaryParameter::input(std::ifstream & fi) {
 	int64_t j, k;
 
-	for (k = 0; k < _nbCluster; k++) {
+  for (k = 0; k < _nbCluster; k++) {
 
-		// Proportions //
-		fi >> _tabProportion[k];
+    // Proportions //
+		_tabProportion[k] = getDoubleFromStream(fi);
 
-		// Centers //
-		for (j = 0; j < _pbDimension; j++) {
+    // Centers //
+    for (j = 0; j < _pbDimension; j++)
 			fi >> _tabCenter[k][j];
-		}
 
 		// Scatters //
-		inputScatter(fi); // virtual
+		inputScatter(fi, k); // virtual
 	}
 }
 
