@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Matrix/DiagMatrix.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -303,18 +303,16 @@ void DiagMatrix::input(std::ifstream & fi) {
 
 	for (p = 0; p < _s_pbDimension; p++) {
 		// useless because all are 0
-		for (q = 0; q < p; q++) {
-			fi >> garbage;
-		}
+    for (q = 0; q < p; q++)
+			getDoubleFromStream(fi);
 
-		// here i==j so we are in the diagonal
-		fi >> _store[p];
+    // here i==j so we are in the diagonal
+		_store[p] = getDoubleFromStream(fi);
 
-		// useless because all are 0
-		for (q = p + 1; q < _s_pbDimension; q++) {
-			fi >> garbage;
-		}
-	}
+    // useless because all are 0
+    for (q = p + 1; q < _s_pbDimension; q++)
+			getDoubleFromStream(fi);
+  }
 }
 
 void DiagMatrix::input(double ** variances) {
